@@ -259,5 +259,8 @@ class ConnectionServiceGrpcAsyncIOTransport(ConnectionServiceTransport):
             )
         return self._stubs["list_connections"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("ConnectionServiceGrpcAsyncIOTransport",)
